@@ -105,8 +105,6 @@ def regressione_lineare(df, lista_colonne_x, colonna_y):
     X = X.values.reshape(-1,len(lista_colonne_x))
     Y = Y.values.reshape(-1,1)
     reg = LinearRegression().fit(X, Y)
-    #plot regression line
-    plt.scatter(X, Y, color='black')
     return reg
 
 ##make funtion to return linear regression on multiple x columns
@@ -125,8 +123,6 @@ def regressione_lineare_avanzata(df, lista_colonne_x, colonna_y, fit_intercept=T
     X = X.values.reshape(-1,len(lista_colonne_x))
     Y = Y.values.reshape(-1,1)
     reg = LinearRegression(fit_intercept=fit_intercept, normalize=normalize, copy_X=copy_X, n_jobs=n_jobs, positive=positive, random_state=random_state).fit(X, Y)
-    #plot regression line
-    plt.scatter(X, Y, color='black')
     return reg
 
 #make funtion to return logistic regression on multiple x columns
