@@ -17,27 +17,11 @@ def rimuovi_caratteri_speciali(df, colonna):
 def rimuovi_caratteri_speciali_e_cifre(df, colonna):
     return(df[colonna].apply(lambda x: x.translate(str.maketrans('', '', '!"#$%&\'()*+,-./:;<=>?@[\\]^_`{|}~0123456789'))))
 
-#make function to remove stopwords from text column with sklearn of specific language
+#make function to remove stopwords from text column of specific language
 def rimuovi_stopwords(df, colonna, lingua):
-    from sklearn.feature_extraction.text import CountVectorizer
-    count_vectorizer = CountVectorizer(stop_words=lingua)
-    count_vectorizer.fit(df[colonna])
-    bag_of_words = count_vectorizer.transform(df[colonna])
-    return(bag_of_words)
-
-#mkae function to return tfidf from text column of dataframe with sklearn
-def vettorizza_testo_sklearn(df, colonna):
-    from sklearn.feature_extraction.text import TfidfTransformer
-    tfidf_transformer = TfidfTransformer()
-    tfidf = tfidf_transformer.fit_transform(bag_of_words(df, colonna))
-    return(tfidf)
-
-#make function to return tokenized text column of dataframe with sklearn
-def tokenizza_testo_sklearn(df, colonna):
-    from sklearn.feature_extraction.text import CountVectorizer
-    count_vectorizer = CountVectorizer()
-    bag_of_words = count_vectorizer.fit_transform(df[colonna])
-    return(bag_of_words)
+    from nltk.corpus import stopwords
+    stop_words = set(stopwords.words(lingua))
+    return(df[colonna].apply(lambda x: ' '.join([word for word in x.split() if word not in stop_words])))
 
 #make function to return tokenized text column of dataframe with texthero
 def tokenizza_testo(df, colonna):
